@@ -14,7 +14,7 @@ import threading
 @click.option('--port', default=8080)
 @click.option('--debug', default=False, is_flag=True,
               help='Whether to run in debug mode.')
-@click.option('--browser/--nobrowser', is_flag=True, default=False,
+@click.option('--browser/--nobrowser', '-b', is_flag=True, default=False,
               help='Whether to open a browser upon startup.')
 @click.option('--skip_sdk_update_check', default=False, is_flag=True,
               help='Whether to skip checking for updates to the Grow SDK.')
@@ -24,7 +24,11 @@ def run(host, port, debug, browser, skip_sdk_update_check, pod_path):
     thread = threading.Thread(target=sdk_utils.check_version, args=(True,))
     thread.start()
   root = os.path.abspath(os.path.join(os.getcwd(), pod_path))
-  environment = env.Env(env.EnvConfig(host=host, port=port, name='dev'))
+  environment = env.Env(env.EnvConfig(
+      host=host,
+      port=port,
+      name='dev',
+      cached=False))
   pod = pods.Pod(root, storage=storage.FileStorage, env=environment)
   try:
     manager.start(pod, host=host, port=port, open_browser=browser, debug=debug)
