@@ -1,7 +1,10 @@
+from . import base
+from . import messages
+import fnmatch
 import mimetypes
 import re
-from grow.pods.controllers import base
 
+# TODO(jeremydw): Move to storage lib.
 try:
   from google.appengine.ext import blobstore
 except ImportError:
@@ -12,9 +15,13 @@ mimetypes.add_type('image/svg+xml', '.svg')
 mimetypes.add_type('text/css', '.css')
 
 
-class StaticController(base.BaseController):
+SKIP_PATTERNS = [
+    '**/.**',
+]
 
-  KIND = 'Static file'
+
+class StaticController(base.BaseController):
+  KIND = messages.Kind.STATIC
 
   def __init__(self, path_format, source_format=None, pod=None):
     # path_format: "serve_at"
@@ -24,6 +31,9 @@ class StaticController(base.BaseController):
     self.pod = pod
     self.route_params = {}
 
+  def __repr__(self):
+    return '<Static(format=\'{}\')>'.format(self.source_format)
+
   def get_pod_path(self):
     return self.source_format.format(**self.route_params)
 
@@ -58,6 +68,16 @@ class StaticController(base.BaseController):
 
       paths = self.pod.list_dir(source)
       paths = [('/' + source + path).replace(self.pod.root, '') for path in paths]
+
+      # Exclude paths matched by skip patterns.
+      for pattern in SKIP_PATTERNS:
+        # .gitignore-style treatment of paths without slashes.
+        if '/' not in pattern:
+          pattern = '**{}**'.format(pattern)
+        for skip_paths in fnmatch.filter(paths, pattern):
+          paths = [path for path in paths
+                   if path.replace(self.pod.root, '') not in skip_paths]
+
       for path in paths:
         for filename in re.findall(source_regex, path):
           params = {'filename': filename}
