@@ -36,6 +36,7 @@ from . import storage
 from . import catalog_holder
 from .collectionz import collectionz
 from .controllers import tags
+from .controllers import jinja2htmlcompress
 from .preprocessors import preprocessors
 from .tests import tests
 from grow.common import utils
@@ -78,6 +79,8 @@ class Pod(object):
     self.catalogs = catalog_holder.Catalogs(pod=self)
     self.tests = tests.Tests(pod=self)
 
+    self._routes = None
+
   def __repr__(self):
     if self.changeset is not None:
       return '<Pod: {}@{}>'.format(self.root, self.changeset)
@@ -92,10 +95,10 @@ class Pod(object):
 
   @property
   def routes(self):
-    # Rebuilding routes with each access of the routes propery prevents
-    # caching issues with data files. TODO: Rebuild routes only when routes
-    # and data files change.
-    return routes.Routes(pod=self)
+    if self.env.cached and self._routes is not None:
+      return self._routes
+    self._routes = routes.Routes(pod=self)
+    return self._routes
 
   def reset_yaml(self):
     self._parse_yaml.reset()
@@ -295,10 +298,16 @@ class Pod(object):
     return self.podspec
 
   def get_template_env(self):
-    _template_loader = self.storage.JinjaLoader(self.root)
-    env = jinja2.Environment(
-        loader=_template_loader, autoescape=True, trim_blocks=True,
-        extensions=['jinja2.ext.i18n', 'jinja2.ext.do'])
+    kwargs = {
+        'autoescape': True,
+        'extensions': ['jinja2.ext.i18n', 'jinja2.ext.do'],
+        'loader': self.storage.JinjaLoader(self.root),
+        'lstrip_blocks': True,
+        'trim_blocks': True,
+    }
+    if self.podspec.flags.get('compress_html'):
+      kwargs['extensions'].append(jinja2htmlcompress.HTMLCompress)
+    env = jinja2.Environment(**kwargs)
     env.filters['markdown'] = tags.markdown_filter
     env.filters['render'] = tags.render_filter
     return env
