@@ -6,7 +6,8 @@ class Podspec(object):
 
   def __init__(self, yaml):
     self.yaml = yaml
-    self.root_path = yaml.get('flags', {}).get('root_path', '').lstrip('/').rstrip('/')
+    self.flags = yaml.get('flags', {})
+    self.root_path = self.flags.get('root_path', '').lstrip('/').rstrip('/')
     self.default_locale = locales.Locale.parse(yaml.get('localization', {}).get('default_locale', None))
     self.fields = yaml
 
